@@ -256,6 +256,18 @@ char * nr2signal(int sig);
  */
 void string2timeval(char * value, struct timeval * t);
 
+/**
+ * double2timeval
+ *
+ * parse double into timeval
+ *
+ * @param[in] value - double value
+ * @param[out] t - pointer to timeval structure
+ *
+ * @return nothing
+ */
+void double2timeval(double value, struct timeval * t);
+
 /**
  * timeval2double
  *
