@@ -22,10 +22,8 @@
  *****************************************************************************/
 
 /* include header */
-#include "utils.h"
 #include "result_thread.h"
 #include "mod_gearman.h"
-#include "gm_log.h"
 #include "gearman.h"
 
 /* specify event broker API version (required) */
@@ -79,19 +77,19 @@ int nebmodule_init( int flags, char *args, nebmodule *handle ) {
     gearman_module_handle=handle;
 
     /* set some module info */
-    neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_TITLE,   "mod_gearman" );
+    neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_TITLE,   "Mod-Gearman" );
     neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_AUTHOR,  "Sven Nierlein" );
-    neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_TITLE,   "Copyright (c) 2010 Sven Nierlein" );
+    neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_TITLE,   "Copyright (c) 2010-2011 Sven Nierlein" );
     neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_VERSION, GM_VERSION );
     neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_LICENSE, "GPL v3" );
     neb_set_module_info( gearman_module_handle, NEBMODULE_MODINFO_DESC,    "distribute host/service checks and eventhandler via gearman" );
 
     mod_gm_opt = malloc(sizeof(mod_gm_opt_t));
     set_default_options(mod_gm_opt);
-    gm_log( GM_LOG_INFO,  "Version %s\n", GM_VERSION );
 
     /* parse arguments */
     read_arguments( args );
+    gm_log( GM_LOG_INFO,  "Version %s\n", GM_VERSION );
     gm_log( GM_LOG_TRACE, "args: %s\n", args );
     gm_log( GM_LOG_TRACE, "nebmodule_init(%i, %i)\n", flags );
     gm_log( GM_LOG_DEBUG, "running on libgearman %s\n", gearman_version() );
@@ -419,7 +417,6 @@ static int handle_host_check( int event_type, void *data ) {
     nebstruct_host_check_data * hostdata;
     char *raw_command=NULL;
     char *processed_command=NULL;
-    struct timeval start_time;
     host * hst;
 
     gm_log( GM_LOG_TRACE, "handle_host_check(%i)\n", event_type );
@@ -446,7 +443,10 @@ static int handle_host_check( int event_type, void *data ) {
     }
 
     /* get objects and set target function */
-    hst = find_host( hostdata->host_name );
+    if((hst=hostdata->object_ptr)==NULL) {
+        gm_log( GM_LOG_ERROR, "Host handler received NULL host object pointer.\n" );
+        return NEBERROR_CALLBACKCANCEL;
+    }
     set_target_queue( hst, NULL );
 
     /* local check? */
@@ -486,9 +486,6 @@ static int handle_host_check( int event_type, void *data ) {
         return NEBERROR_CALLBACKCANCEL;
     }
 
-    /* get the command start time */
-    gettimeofday(&start_time,NULL);
-
     /* increment number of host checks that are currently running */
     currently_running_host_checks++;
 
@@ -498,11 +495,10 @@ static int handle_host_check( int event_type, void *data ) {
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
     temp_buffer[0]='\x0';
-    snprintf( temp_buffer,sizeof( temp_buffer )-1,"type=host\nresult_queue=%s\nhost_name=%s\nstart_time=%i.%i\ntimeout=%d\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,sizeof( temp_buffer )-1,"type=host\nresult_queue=%s\nhost_name=%s\nstart_time=%i.0\ntimeout=%d\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               hst->name,
-              ( int )start_time.tv_sec,
-              ( int )start_time.tv_usec,
+              ( int )hst->next_check,
               host_check_timeout,
               processed_command
             );
@@ -549,7 +545,6 @@ static int handle_svc_check( int event_type, void *data ) {
     service * svc = NULL;
     char *raw_command=NULL;
     char *processed_command=NULL;
-    struct timeval start_time;
     nebstruct_service_check_data * svcdata;
     int prio = GM_JOB_PRIO_LOW;
 
@@ -570,11 +565,16 @@ static int handle_svc_check( int event_type, void *data ) {
     }
 
     /* get objects and set target function */
-    svc = find_service( svcdata->host_name, svcdata->service_description );
+    if((svc=svcdata->object_ptr)==NULL) {
+        gm_log( GM_LOG_ERROR, "Service handler received NULL service object pointer.\n" );
+        return NEBERROR_CALLBACKCANCEL;
+    }
 
     /* find the host associated with this service */
-    if((hst=svc->host_ptr)==NULL)
+    if((hst=svc->host_ptr)==NULL) {
+        gm_log( GM_LOG_ERROR, "Service handler received NULL host object pointer.\n" );
         return NEBERROR_CALLBACKCANCEL;
+    }
     set_target_queue( hst, svc );
 
     /* local check? */
@@ -611,9 +611,6 @@ static int handle_svc_check( int event_type, void *data ) {
         return NEBERROR_CALLBACKCANCEL;
     }
 
-    /* get the command start time */
-    gettimeofday(&start_time,NULL);
-
     /* increment number of service checks that are currently running... */
     currently_running_service_checks++;
 
@@ -624,12 +621,11 @@ static int handle_svc_check( int event_type, void *data ) {
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
     temp_buffer[0]='\x0';
-    snprintf( temp_buffer,sizeof( temp_buffer )-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\nstart_time=%i.%i\ntimeout=%d\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,sizeof( temp_buffer )-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\nstart_time=%i.0\ntimeout=%d\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               svcdata->host_name,
               svcdata->service_description,
-              ( int )start_time.tv_sec,
-              ( int )start_time.tv_usec,
+              ( int )svc->next_check,
               service_check_timeout,
               processed_command
             );
@@ -714,14 +710,29 @@ static int read_arguments( const char *args_orig ) {
 
 /* verify our option */
 static int verify_options(mod_gm_opt_t *opt) {
+
+    /* open new logfile */
+    if ( opt->logmode == GM_LOG_MODE_AUTO && opt->logfile ) {
+        opt->logmode = GM_LOG_MODE_FILE;
+    }
+    if(opt->logmode == GM_LOG_MODE_FILE && opt->logfile && opt->debug_level < GM_LOG_STDOUT) {
+        opt->logfile_fp = fopen(opt->logfile, "a+");
+        if(opt->logfile_fp == NULL) {
+            gm_log( GM_LOG_ERROR, "error opening logfile: %s\n", opt->logfile );
+        }
+    }
+    if ( opt->logmode == GM_LOG_MODE_AUTO ) {
+        opt->logmode = GM_LOG_MODE_CORE;
+    }
+
     /* did we get any server? */
     if(opt->server_num == 0) {
         gm_log( GM_LOG_ERROR, "please specify at least one server\n" );
         return(GM_ERROR);
     }
 
-    if ( mod_gm_opt->result_queue == NULL )
-        mod_gm_opt->result_queue = GM_DEFAULT_RESULT_QUEUE;
+    if ( opt->result_queue == NULL )
+        opt->result_queue = GM_DEFAULT_RESULT_QUEUE;
 
     /* nothing set by hand -> defaults */
     if( opt->set_queues_by_hand == 0 ) {
@@ -731,28 +742,6 @@ static int verify_options(mod_gm_opt_t *opt) {
         opt->events   = GM_ENABLED;
     }
 
-    if(   opt->servicegroups_num == 0
-       && opt->hostgroups_num    == 0
-       && opt->exports_count     == 0
-       && opt->hosts             == GM_DISABLED
-       && opt->services          == GM_DISABLED
-       && opt->events            == GM_DISABLED
-       && opt->perfdata          == GM_DISABLED
-      ) {
-        gm_log( GM_LOG_ERROR, "loading Mod-Gearman NEB module without any queues is useless\n" );
-        return(GM_ERROR);
-    }
-
-    /* do we need a result thread? */
-    if(   opt->servicegroups_num == 0
-       && opt->hostgroups_num    == 0
-       && opt->hosts    == GM_DISABLED
-       && opt->services == GM_DISABLED
-      ) {
-        gm_log( GM_LOG_DEBUG, "disabled unused result threads\n" );
-        mod_gm_opt->result_workers = 0;
-    }
-
     return(GM_OK);
 }
 
@@ -1113,3 +1102,10 @@ int handle_export(int callback_type, void *data) {
     mod_gm_opt->debug_level = debug_level_orig;
     return return_code;
 }
+
+
+/* core log wrapper */
+void write_core_log(char *data) {
+    write_to_all_logs( data, NSLOG_INFO_MESSAGE );
+    return;
+}
